@@ -7,6 +7,7 @@
 #include <QtCore/QCoreApplication>
 #include <QProcess>
 #include <QtGui/QMessageBox>
+#include <QDesktopServices>
 
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::MainWindow),
@@ -97,9 +98,7 @@ void MainWindow::on_capital_clicked()
 
 void MainWindow::on_cielo_clicked()
 {
-    QProcess process;
-    process.start("sh /opt/serviziopubblico/script/cielo.sh");
-    process.waitForFinished();
+    QDesktopServices::openUrl(QUrl("http://www.cielotv.it/cielolive.html"));
 }
 
 void MainWindow::on_ditv_clicked()
@@ -158,9 +157,7 @@ void MainWindow::on_actionRicorda_un_amico_triggered()
 
 void MainWindow::on_actionDonazione_triggered()
 {
-    QProcess process;
-    process.start("sh /opt/serviziopubblico/script/donate.sh");
-    process.waitForFinished();
+    QDesktopServices::openUrl(QUrl("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=7CAMBWQUJSJJN"));
 }
 
 void MainWindow::on_actionPuntate_triggered()
