@@ -3,10 +3,13 @@
 
 #include <QtGui/QMainWindow>
 
+#include "browser.h"
+
 class PuntateForm;
-class SocialNetwork;
+//class SocialNetwork;
 class Credits;
 class OptionsForm;
+class Browser;
 
 namespace Ui {
     class MainWindow;
@@ -55,16 +58,20 @@ private slots:
 
     void on_actionPuntate_triggered();
 
-    void on_actionSocial_Network_triggered();
-
     void on_actionCredits_triggered();
 
+    void on_actionFacebook_triggered();
+
+    void on_actionTwitter_triggered();
+
+    void on_actionVauro_triggered();
+
 private:
     Ui::MainWindow *ui;
     PuntateForm *puntateForm;
-    SocialNetwork *socialNetwork;
     Credits *credits;
     OptionsForm *optionsForm;
+    Browser *browser;
 };
 
 #endif // MAINWINDOW_H
